@@ -15,7 +15,6 @@ import types
 from contextlib import contextmanager
 from copy import copy
 from distutils.version import LooseVersion
-from typing import TYPE_CHECKING
 
 import docutils
 from docutils import nodes
@@ -31,7 +30,8 @@ from sphinx.util import logging
 logger = logging.getLogger(__name__)
 report_re = re.compile('^(.+?:(?:\\d+)?): \\((DEBUG|INFO|WARNING|ERROR|SEVERE)/(\\d+)?\\) ')
 
-if TYPE_CHECKING:
+if False:
+    # For type annotation
     from typing import Any, Callable, Generator, Iterator, List, Tuple  # NOQA
     from docutils.statemachine import State, ViewList  # NOQA
     from sphinx.environment import BuildEnvironment  # NOQA
@@ -185,6 +185,14 @@ class LoggingReporter(Reporter):
                           stream, debug, error_handler=error_handler)
 
 
+class NullReporter(Reporter):
+    """A dummy reporter; write nothing."""
+
+    def __init__(self):
+        # type: () -> None
+        Reporter.__init__(self, '', 999, 4)
+
+
 def is_html5_writer_available():
     # type: () -> bool
     return __version_info__ > (0, 13, 0)
